@@ -2029,7 +2029,7 @@ class VisualizationFunctions:
                     newColor = ','.join(nodeColors[sources[i]].split(',')[:3] + ['0.6)'])
                     colorscales[i] = dict(label=labels[i], colorscale=[[0, newColor], [1, newColor]])
 
-        fig = plotly.graph_objects.Figure(data=[plotly.graph_objects.Sankey(valueformat = '', valuesuffix = '',
+        fig = go.Figure(data=[go.Sankey(valueformat = '', valuesuffix = '',
             node = dict(pad = 20, thickness = 40, line = dict(color = 'white', width = 0.5), label = nodeLabels, color = nodeColors,),
             link = dict(source = sources, target = targets, value = values, label = labels, colorscales = colorscales, hoverinfo='all'))]) #line ={'color':'rgba(255,0,0,0.8)', 'width':0.1}
 
